"""
Configs migration

Generation datetime: 2021-02-02 20:26:42.551341
"""

from typing import List

from configs_core.migration.db_migrate_helper import DatabaseMigrationHelper as mh, LimitationToModify

REVISION = "7c9e285c"
DOWN_REVISION = "f42525e2"


limitationsToModify: List[LimitationToModify] = []


def upgrade():
    """Upgrade configs to new revision"""

    # limitations to add
    mh.addLimitation(
        limitationName="LUNA_HANDLERS_LIVENESS_SETTINGS",
        validationSchema={
            "type": "object",
            "properties": {
                "real_threshold": {"type": "number", "minimum": 0, "maximum": 1},
                "use_filter": {"type": "integer", "enum": [0, 1]},
                "minimum_detection_size": {"type": "integer"},
                "border_distance": {"type": "integer"},
                "principal_axes": {"type": "integer"},
            },
            "description": "FSDK one shot liveness settings",
            "required": [
                "use_filter",
                "minimum_detection_size",
                "border_distance",
                "principal_axes",
            ],
            "additionalProperties": False,
        },
        defaultValue={
            "real_threshold": 0.88,
            "use_filter": 0,
            "minimum_detection_size": 200,
            "border_distance": 10,
            "principal_axes": 25,
        },
        description="FSDK one shot liveness settings",
        services=["luna-handlers"],
        groupNames=["luna-platform", "luna-api sdk settings"],
    )

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)


def downgrade():
    """Downgrade configs to previous revision"""

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)

    # limitations to remove
    mh.removeLimitation(limitationName="LUNA_HANDLERS_LIVENESS_SETTINGS")
