"""
Configs migration

Generation datetime: 2024-07-01 11:03:59.817346
"""

from configs_core.migration.db_migrate_helper import (
    DatabaseMigrationHelper,
    ExternalLimitationToModify,
    LimitationToModify,
)

mh: DatabaseMigrationHelper

REVISION = "4c77698d"
DOWN_REVISION = "614fd8ec"


def upgradeFunction(setting: dict):
    setting["timeouts"] = {
        "connect": 30.0,
        "request": 60.0,
        "sock_connect": 10.0,
        "sock_read": 60.0,
    }
    return setting


def downgradeFunction(setting: dict):
    setting.pop("timeouts", None)
    return setting


limitationsToModify: list[LimitationToModify] = [
    LimitationToModify(
        limitationName="LUNA_REMOTE_SDK_VIDEO_SETTINGS",
        oldValidationSchema={
            "type": "object",
            "properties": {
                "decoder_device_class": {
                    "type": "string",
                    "enum": ["cpu", "gpu", "auto"],
                },
                "decoder_worker_count": {"type": "integer", "minimum": 1},
                "storage": {"type": "string"},
                "max_size": {"type": "integer", "minimum": 1},
            },
            "description": "sdk video processing settings",
            "additionalProperties": False,
        },
        newValidationSchema={
            "type": "object",
            "properties": {
                "decoder_device_class": {
                    "type": "string",
                    "enum": ["cpu", "gpu", "auto"],
                },
                "decoder_worker_count": {"type": "integer", "minimum": 1},
                "storage": {"type": "string"},
                "max_size": {"type": "integer", "minimum": 1},
                "timeouts": {
                    "type": "object",
                    "properties": {
                        "request": {"type": "number", "exclusiveMinimum": 0},
                        "connect": {"type": "number", "exclusiveMinimum": 0},
                        "sock_connect": {"type": "number", "exclusiveMinimum": 0},
                        "sock_read": {"type": "number", "exclusiveMinimum": 0},
                    },
                    "description": "timeouts in seconds",
                    "additionalProperties": False,
                },
            },
            "description": "sdk video processing settings",
            "additionalProperties": False,
        },
        oldDefaultValue={
            "decoder_device_class": "auto",
            "decoder_worker_count": 10,
            "storage": "./videos",
            "max_size": 1024,
        },
        newDefaultValue={
            "decoder_device_class": "auto",
            "decoder_worker_count": 10,
            "storage": "./videos",
            "max_size": 1024,
            "timeouts": {
                "connect": 30.0,
                "request": 60.0,
                "sock_connect": 10.0,
                "sock_read": 60.0,
            },
        },
        settingUpgradeFunction=upgradeFunction,
        settingDowngradeFunction=downgradeFunction,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-remote-sdk"],
        newServices=["luna-remote-sdk"],
    ),
]

externalLimitationsToModify: list[ExternalLimitationToModify] = []


def upgrade():
    """Upgrade configs to new revision"""

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)

    for limitation in externalLimitationsToModify:
        mh.migrateLimitation(limitation)


def downgrade():
    """Downgrade configs to previous revision"""

    # limitations to modify
    for limitation in externalLimitationsToModify:
        mh.migrateLimitation(limitation)

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)
