"""
Configs migration

Generation datetime: 2024-07-02 13:26:30.189214
"""

from configs_core.migration.db_migrate_helper import (
    DatabaseMigrationHelper,
    ExternalLimitationToModify,
    LimitationToModify,
)

mh: DatabaseMigrationHelper

REVISION = "05c7aac2"
DOWN_REVISION = "4c77698d"


def upgradeFunction(setting: dict):
    setting["timeouts"] = {
        "connect": 30.0,
        "request": 60.0,
        "sock_connect": 10.0,
        "sock_read": 60.0,
    }
    return setting


def downgradeFunction(setting: dict):
    setting.pop("timeouts")
    return setting


limitationsToModify: list[LimitationToModify] = [
    LimitationToModify(
        limitationName="LUNA_VIDEO_AGENT_VIDEO_SETTINGS",
        oldValidationSchema={
            "type": "object",
            "properties": {
                "decoder_device_class": {
                    "type": "string",
                    "enum": ["cpu", "gpu", "auto"],
                },
                "decoder_worker_count": {"type": "integer", "minimum": 1},
                "max_size": {"type": "integer", "minimum": 1},
            },
            "description": "video processing settings",
            "additionalProperties": False,
        },
        newValidationSchema={
            "type": "object",
            "properties": {
                "decoder_device_class": {
                    "type": "string",
                    "enum": ["cpu", "gpu", "auto"],
                },
                "decoder_worker_count": {"type": "integer", "minimum": 1},
                "max_size": {"type": "integer", "minimum": 1},
                "timeouts": {
                    "type": "object",
                    "properties": {
                        "request": {"type": "number", "exclusiveMinimum": 0},
                        "connect": {"type": "number", "exclusiveMinimum": 0},
                        "sock_connect": {"type": "number", "exclusiveMinimum": 0},
                        "sock_read": {"type": "number", "exclusiveMinimum": 0},
                    },
                    "description": "timeouts in seconds",
                    "additionalProperties": False,
                },
            },
            "description": "video processing settings",
            "additionalProperties": False,
        },
        oldDefaultValue={
            "decoder_device_class": "auto",
            "decoder_worker_count": 10,
            "max_size": 2048,
        },
        newDefaultValue={
            "decoder_device_class": "auto",
            "decoder_worker_count": 10,
            "max_size": 2048,
            "timeouts": {
                "connect": 30.0,
                "request": 60.0,
                "sock_connect": 10.0,
                "sock_read": 60.0,
            },
        },
        oldDescription="luna-video-agent video processing settings",
        newDescription="luna-video-agent video processing settings",
        oldGroupNames=["luna-platform"],
        newGroupNames=["luna-platform"],
        settingUpgradeFunction=upgradeFunction,
        settingDowngradeFunction=downgradeFunction,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-video-agent"],
        newServices=["luna-video-agent"],
    ),
]

externalLimitationsToModify: list[ExternalLimitationToModify] = []


def upgrade():
    """Upgrade configs to new revision"""

    # limitations to add
    mh.addLimitation(
        limitationName="LUNA_VIDEO_AGENT_SETTINGS",
        validationSchema={
            "type": "object",
            "properties": {"max_active_streams": {"type": "integer", "minimum": 1}},
            "description": "extended video agent settings",
            "additionalProperties": False,
        },
        defaultValue={"max_active_streams": 2},
        description="settings for luna-video-agent",
        services=["luna-video-agent"],
        groupNames=["luna-platform", "luna-handlers-estimators-settings"],
    )

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)

    for limitation in externalLimitationsToModify:
        mh.migrateLimitation(limitation)


def downgrade():
    """Downgrade configs to previous revision"""

    # limitations to modify
    for limitation in externalLimitationsToModify:
        mh.migrateLimitation(limitation)

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)

    # limitations to remove
    mh.removeLimitation(limitationName="LUNA_VIDEO_AGENT_SETTINGS")
