"""
Configs migration

Generation datetime: 2024-08-23 18:53:16.771118
"""

from configs_core.migration.db_migrate_helper import (
    DatabaseMigrationHelper,
    ExternalLimitationToModify,
    LimitationToModify,
)

mh: DatabaseMigrationHelper

REVISION = "e7b16817"
DOWN_REVISION = "a6e4f71a"


def upgradeFunction(setting: dict):
    setting["estimator_settings"].pop("quality_threshold", None)
    return setting


def downgradeFunction(setting: dict):
    setting["estimator_settings"]["quality_threshold"] = 0.5
    return setting


limitationsToModify: list[LimitationToModify] = [
    LimitationToModify(
        limitationName="LUNA_REMOTE_SDK_LIVENESS_ESTIMATOR_SETTINGS",
        oldValidationSchema={
            "type": "object",
            "properties": {
                "runtime_settings": {
                    "type": "object",
                    "properties": {
                        "device_class": {
                            "type": "string",
                            "enum": ["global", "cpu", "gpu"],
                        },
                        "optimal_batch_size": {"type": "integer", "minimum": 1},
                        "worker_count": {"type": "integer", "minimum": 1},
                    },
                    "additionalProperties": False,
                },
                "estimator_settings": {
                    "type": "object",
                    "properties": {
                        "real_threshold": {
                            "type": "number",
                            "minimum": 0,
                            "maximum": 1,
                        },
                        "quality_threshold": {
                            "type": "number",
                            "minimum": 0,
                            "maximum": 1,
                        },
                    },
                    "description": "FSDK one shot liveness settings",
                    "additionalProperties": False,
                },
            },
            "description": "settings for sdk liveness estimator",
            "additionalProperties": False,
        },
        newValidationSchema={
            "type": "object",
            "properties": {
                "runtime_settings": {
                    "type": "object",
                    "properties": {
                        "device_class": {
                            "type": "string",
                            "enum": ["global", "cpu", "gpu"],
                        },
                        "optimal_batch_size": {"type": "integer", "minimum": 1},
                        "worker_count": {"type": "integer", "minimum": 1},
                    },
                    "additionalProperties": False,
                },
                "estimator_settings": {
                    "type": "object",
                    "properties": {"real_threshold": {"type": "number", "minimum": 0, "maximum": 1}},
                    "description": "FSDK one shot liveness settings",
                    "additionalProperties": False,
                },
            },
            "description": "settings for sdk liveness estimator",
            "additionalProperties": False,
        },
        oldDefaultValue={
            "runtime_settings": {
                "device_class": "global",
                "optimal_batch_size": 10,
                "worker_count": 1,
            },
            "estimator_settings": {"real_threshold": 0.5, "quality_threshold": 0.5},
        },
        newDefaultValue={
            "runtime_settings": {
                "device_class": "global",
                "optimal_batch_size": 10,
                "worker_count": 1,
            },
            "estimator_settings": {"real_threshold": 0.5},
        },
        oldDescription="luna-remote-sdk settings for liveness estimation in handlers",
        newDescription="luna-remote-sdk settings for liveness estimation in handlers",
        oldGroupNames=["luna-platform", "luna-handlers-estimators-settings"],
        newGroupNames=["luna-platform", "luna-handlers-estimators-settings"],
        settingUpgradeFunction=upgradeFunction,
        settingDowngradeFunction=downgradeFunction,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-remote-sdk"],
        newServices=["luna-remote-sdk"],
    ),
]

externalLimitationsToModify: list[ExternalLimitationToModify] = []


def upgrade():
    """Upgrade configs to new revision"""

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)

    for limitation in externalLimitationsToModify:
        mh.migrateLimitation(limitation)


def downgrade():
    """Downgrade configs to previous revision"""

    # limitations to modify
    for limitation in externalLimitationsToModify:
        mh.migrateLimitation(limitation)

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)
