"""
Configs migration

Generation datetime: 2024-10-03 21:58:16.963797
"""

from configs_core.migration.db_migrate_helper import (
    DatabaseMigrationHelper,
    ExternalLimitationToModify,
    LimitationToModify,
)

mh: DatabaseMigrationHelper

REVISION = "4e314cea"
DOWN_REVISION = "fba46275"


limitationsToModify: list[LimitationToModify] = []

externalLimitationsToModify: list[ExternalLimitationToModify] = []


def upgrade():
    """Upgrade configs to new revision"""

    # limitations to add
    mh.addLimitation(
        limitationName="LUNA_REMOTE_SDK_HUMAN_TRACKER_SETTINGS",
        validationSchema={
            "type": "object",
            "properties": {
                "runtime_settings": {
                    "type": "object",
                    "properties": {
                        "device_class": {
                            "type": "string",
                            "enum": ["global", "cpu", "gpu"],
                        },
                        "optimal_batch_size": {"type": "integer", "minimum": 1},
                    },
                    "additionalProperties": False,
                },
                "estimator_settings": {
                    "type": "object",
                    "properties": {
                        "detector_step": {"type": "integer", "minimum": 1},
                        "scale_result_size": {"type": "integer", "minimum": 1},
                        "skip_frames": {"type": "integer", "minimum": 1},
                    },
                    "additionalProperties": False,
                    "description": "tracker settings",
                },
            },
            "description": "settings for sdk estimator",
            "additionalProperties": False,
        },
        defaultValue={
            "runtime_settings": {"device_class": "global", "optimal_batch_size": 100},
            "estimator_settings": {
                "detector_step": 7,
                "scale_result_size": 640,
                "skip_frames": 18,
            },
        },
        description="luna-remote-sdk settings for trackengine",
        services=["luna-remote-sdk"],
        groupNames=["luna-platform", "luna-handlers-estimators-settings"],
    )

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)

    for limitation in externalLimitationsToModify:
        mh.migrateLimitation(limitation)


def downgrade():
    """Downgrade configs to previous revision"""

    # limitations to modify
    for limitation in externalLimitationsToModify:
        mh.migrateLimitation(limitation)

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)

    # limitations to remove
    mh.removeLimitation(limitationName="LUNA_REMOTE_SDK_HUMAN_TRACKER_SETTINGS")
